summaryrefslogtreecommitdiff
path: root/tlsexternalcertprovider/build.gradle
diff options
context:
space:
mode:
Diffstat (limited to 'tlsexternalcertprovider/build.gradle')
-rw-r--r--tlsexternalcertprovider/build.gradle29
1 files changed, 15 insertions, 14 deletions
diff --git a/tlsexternalcertprovider/build.gradle b/tlsexternalcertprovider/build.gradle
index ddf7cafd..bb50eb03 100644
--- a/tlsexternalcertprovider/build.gradle
+++ b/tlsexternalcertprovider/build.gradle
@@ -3,20 +3,17 @@
* Distributed under the GNU GPL v2 with additional terms. For full terms see the file doc/LICENSE.txt
*/
-apply plugin: 'com.android.application'
-
-ext {
- bouncycastleVersion = '1.49'
+plugins {
+ alias libs.plugins.android.application
}
android {
- compileSdkVersion 27
-
+ compileSdkVersion 34
defaultConfig {
applicationId "de.blinkt.externalcertprovider"
- minSdkVersion 16
- targetSdkVersion 27
+ minSdkVersion 21
+ targetSdkVersion 34
versionCode 1
versionName "1.0"
@@ -38,6 +35,10 @@ android {
lint {
abortOnError false
}
+ namespace 'de.blinkt.externalcertprovider'
+ buildFeatures {
+ aidl true
+ }
// This is just a demo package, don't care about it being perfect
}
@@ -45,12 +46,12 @@ android {
dependencies {
implementation fileTree(dir: 'libs', include: ['*.jar'])
implementation (
- //'org.bouncycastle:bcprov-jdk15on:' + bouncycastleVersion,
- //'org.bouncycastle:bcprov-ext-jdk15on:' + bouncycastleVersion,
- //'org.bouncycastle:bcpkix-jdk15on:' + bouncycastleVersion,
- 'org.bouncycastle:bcmail-jdk15on:' + bouncycastleVersion,
- //'org.bouncycastle:bcpg-jdk15on:' + bouncycastleVersion
+// libs.org.bouncycastle.bcprov.jdk15on,
+// libs.org.bouncycastle.bcprov.ext.jdk15on,
+// libs.org.bouncycastle.bcpkix.jdk15on,
+ libs.org.bouncycastle.bcmail.jdk15on,
+// libs.org.bouncycastle.bcpg.jdk15on,
)
- testImplementation 'junit:junit:4.12'
+ testImplementation(libs.junit)
}